package com.ruoyi.record.mapper;

import java.util.List;
import com.ruoyi.record.domain.RecordBusbarTemp;

/**
 * 母排测温信息Mapper接口
 * 
 * @author zangch
 * @date 2024-11-07
 */
public interface RecordBusbarTempMapper 
{
    /**
     * 查询母排测温信息
     * 
     * @param objId 母排测温信息主键
     * @return 母排测温信息
     */
    public RecordBusbarTemp selectRecordBusbarTempByObjId(Long objId);

    /**
     * 查询母排测温信息列表
     * 
     * @param recordBusbarTemp 母排测温信息
     * @return 母排测温信息集合
     */
    public List<RecordBusbarTemp> selectRecordBusbarTempList(RecordBusbarTemp recordBusbarTemp);

    /**
     * 新增母排测温信息
     * 
     * @param recordBusbarTemp 母排测温信息
     * @return 结果
     */
    public int insertRecordBusbarTemp(RecordBusbarTemp recordBusbarTemp);

    /**
     * 修改母排测温信息
     * 
     * @param recordBusbarTemp 母排测温信息
     * @return 结果
     */
    public int updateRecordBusbarTemp(RecordBusbarTemp recordBusbarTemp);

    /**
     * 删除母排测温信息
     * 
     * @param objId 母排测温信息主键
     * @return 结果
     */
    public int deleteRecordBusbarTempByObjId(Long objId);

    /**
     * 批量删除母排测温信息
     * 
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordBusbarTempByObjIds(Long[] objIds);
}
